@@ -1,12 +1,13 @@
 from typing import Any, Dict, Optional
 
 from ..bibtex.entry import BibtexEntry
+from ..utils.safe_json import JSONType
 
 
 class DataDump:
     """Contains fields for all entries"""
 
-    results: Dict[str, Optional[Dict[str, str]]]
+    results: Dict[str, Optional[Dict[str, JSONType]]]
     id: str
     new_fields: int
 
@@ -15,13 +16,15 @@ class DataDump:
         self.new_fields = 0
         self.results = {}
 
-    def add_entry(self, lookup_name: str, entry: Optional[BibtexEntry]) -> None:
-        values = (
-            {key: val for key, val in entry._entry.items() if val is not None}
-            if entry is not None
-            else None
-        )
-        self.results[lookup_name] = values
+    def add_entry(
+        self, lookup_name: str, entry: Optional[BibtexEntry], info: Dict[str, JSONType]
+    ) -> None:
+        if entry is None:
+            self.results[lookup_name] = None
+            return
+        infos = {"query-" + key: val for key, val in info.items()}
+        infos.update({key: val for key, val in entry._entry.items() if val is not None})
+        self.results[lookup_name] = infos
 
     def to_dict(self) -> Dict[str, Any]:
         json: Dict[str, Any] = {
