@@ -8,6 +8,7 @@ from pathlib import Path
 from typing import Iterable, List, TypeVar
 
 from ..APIs import LOOKUP_NAMES
+from ..bibtex.entry import FieldNamesSet
 from ..utils.constants import BTAC_FILENAME, CONNECTION_TIMEOUT, SCRIPT_NAME
 from ..utils.logger import logger
 
@@ -105,6 +106,8 @@ parser = ArgumentParser(
     usage="btac [--options] <input_files>\nSee help for a list of options.\n",
 )
 
+FIELD_NAMES = sorted(FieldNamesSet)
+
 parser.add_argument(
     "--dont-query", "-Q", action="append", default=[], choices=LOOKUP_NAMES
 )
@@ -112,16 +115,14 @@ parser.add_argument(
     "--only-query", "-q", action="append", default=[], choices=LOOKUP_NAMES
 )
 parser.add_argument(
-    "--dont-complete",
-    "-C",
-    action="append",
-    default=[],
+    "--dont-complete", "-C", action="append", default=[], choices=FIELD_NAMES
 )
 parser.add_argument(
     "--only-complete",
     "-c",
     action="append",
     default=[],
+    choices=FIELD_NAMES,
 )
 parser.add_argument("--exclude-entry", "-E", action="append", default=[])
 parser.add_argument("--only-entry", "-e", action="append", default=[])
@@ -132,6 +133,7 @@ parser.add_argument("--no-trailing-comma", "--fl", action="store_false")
 parser.add_argument("--indent", "--fi", default="\t")
 
 parser.add_argument("--force-overwrite", "-f", action="store_true")
+parser.add_argument("--prefix", "-p", action="store_true")
 parser.add_argument("--inplace", "-i", action="store_true")
 parser.add_argument("--timeout", "-t", type=float, default=CONNECTION_TIMEOUT)
 parser.add_argument("--verbose", "-v", action="count", default=0)
@@ -191,6 +193,10 @@ Polls the following databases:
         ignores any specified output files
   {FgYellow}-f --force-overwrite{Reset}  Overwrite already present fields
         The default is to overwrite a field if it is empty or absent
+  {FgYellow}-p --prefix{Reset}           Write new fields with a prefix
+        eg: will write "BTACtitle = ..." instead of "title = ..." in the bib file.
+        Can overwrite existing fields starting with BTACxxxx, even without the -f option.
+        Can be combined with -f to safely show info for already present fields.
   {FgYellow}-t --timeout{Reset} {FgGreen}<float>{Reset}  set timeout on request, default: {TIMEOUT} s
   {FgYellow}-S --ignore-ssl{Reset}       Ignore SSL verification when performing queries
 
