@@ -4,6 +4,7 @@ Combine all the mixins into full fledge classes
 
 from xml.etree.ElementTree import Element
 
+from ..bibtex.entry import BibtexEntry
 from ..utils.safe_json import SafeJSON
 from .condition_mixin import FieldConditionMixin
 from .https import HTTPSRateCapedLookup
@@ -20,7 +21,7 @@ class JSON_DAT_Lookup(
     FieldConditionMixin,
     DATQueryMixin,
     EntryMatchSearchMixin[SafeJSON],
-    HTTPSRateCapedLookup,
+    HTTPSRateCapedLookup[BibtexEntry, BibtexEntry],
 ):
     pass
 
@@ -29,7 +30,7 @@ class JSON_DT_Lookup(
     FieldConditionMixin,
     DTQueryMixin,
     EntryMatchSearchMixin[SafeJSON],
-    HTTPSRateCapedLookup,
+    HTTPSRateCapedLookup[BibtexEntry, BibtexEntry],
 ):
     pass
 
@@ -38,7 +39,7 @@ class JSON_AT_Lookup(
     FieldConditionMixin,
     TitleAuthorQueryMixin,
     EntryMatchSearchMixin[SafeJSON],
-    HTTPSRateCapedLookup,
+    HTTPSRateCapedLookup[BibtexEntry, BibtexEntry],
 ):
     pass
 
@@ -47,6 +48,6 @@ class XML_T_Lookup(
     FieldConditionMixin,
     TitleQueryMixin,
     EntryMatchSearchMixin[Element],
-    HTTPSRateCapedLookup,
+    HTTPSRateCapedLookup[BibtexEntry, BibtexEntry],
 ):
     pass
