@@ -13,9 +13,9 @@ DESCRIPTION = "Module to complete bibtex files by polling online databases"
 
 VERSION_MAJOR = 1
 VERSION_MINOR = 1
-VERSION_PATCH = 3
+VERSION_PATCH = 5
 
-VERSION_DATE = "2022-08-13"
+VERSION_DATE = "2022-09-21"
 
 VERSION = (VERSION_MAJOR, VERSION_MINOR, VERSION_PATCH)
 VERSION_STR = f"{VERSION_MAJOR}.{VERSION_MINOR}.{VERSION_PATCH}"
@@ -40,3 +40,6 @@ BTAC_FILENAME = "{name}.btac{suffix}"
 # Most APIs allow to limit the number of results returned for a search query
 # This allows for smaller data transfers
 QUERY_MAX_RESULTS = 3
+
+# Prefix added to fields with -p / --prefix option
+FIELD_PREFIX = "BTAC"
